==> openshift-model-operatorhub-5.9.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/ClusterServiceVersionConditionFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ClusterServiceVersionConditionFluent<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionConditionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getLastTransitionTime();
  public A withLastTransitionTime(java.lang.String lastTransitionTime);
  public java.lang.Boolean hasLastTransitionTime();
  
  /**
   * Method is deprecated. use withLastTransitionTime instead.
   */
  @java.lang.Deprecated
  public A withNewLastTransitionTime(java.lang.String arg0);
  public java.lang.String getLastUpdateTime();
  public A withLastUpdateTime(java.lang.String lastUpdateTime);
  public java.lang.Boolean hasLastUpdateTime();
  
  /**
   * Method is deprecated. use withLastUpdateTime instead.
   */
  @java.lang.Deprecated
  public A withNewLastUpdateTime(java.lang.String arg0);
  public java.lang.String getMessage();
  public A withMessage(java.lang.String message);
  public java.lang.Boolean hasMessage();
  
  /**
   * Method is deprecated. use withMessage instead.
   */
  @java.lang.Deprecated
  public A withNewMessage(java.lang.String arg0);
  public java.lang.String getPhase();
  public A withPhase(java.lang.String phase);
  public java.lang.Boolean hasPhase();
  
  /**
   * Method is deprecated. use withPhase instead.
   */
  @java.lang.Deprecated
  public A withNewPhase(java.lang.String arg0);
  public java.lang.String getReason();
  public A withReason(java.lang.String reason);
  public java.lang.Boolean hasReason();
  
  /**
   * Method is deprecated. use withReason instead.
   */
  @java.lang.Deprecated
  public A withNewReason(java.lang.String arg0);
  
}

==> openshift-model-operatorhub-5.12.2-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/ClusterServiceVersionConditionFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface ClusterServiceVersionConditionFluent<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionConditionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getLastTransitionTime();
  public A withLastTransitionTime(java.lang.String lastTransitionTime);
  public java.lang.Boolean hasLastTransitionTime();
  
  /**
   * Method is deprecated. use withLastTransitionTime instead.
   */
  @java.lang.Deprecated
  public A withNewLastTransitionTime(java.lang.String arg0);
  public java.lang.String getLastUpdateTime();
  public A withLastUpdateTime(java.lang.String lastUpdateTime);
  public java.lang.Boolean hasLastUpdateTime();
  
  /**
   * Method is deprecated. use withLastUpdateTime instead.
   */
  @java.lang.Deprecated
  public A withNewLastUpdateTime(java.lang.String arg0);
  public java.lang.String getMessage();
  public A withMessage(java.lang.String message);
  public java.lang.Boolean hasMessage();
  
  /**
   * Method is deprecated. use withMessage instead.
   */
  @java.lang.Deprecated
  public A withNewMessage(java.lang.String arg0);
  public java.lang.String getPhase();
  public A withPhase(java.lang.String phase);
  public java.lang.Boolean hasPhase();
  
  /**
   * Method is deprecated. use withPhase instead.
   */
  @java.lang.Deprecated
  public A withNewPhase(java.lang.String arg0);
  public java.lang.String getReason();
  public A withReason(java.lang.String reason);
  public java.lang.Boolean hasReason();
  
  /**
   * Method is deprecated. use withReason instead.
   */
  @java.lang.Deprecated
  public A withNewReason(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}
